=== added file 'cmake/CompizTesting.cmake'
--- cmake/CompizTesting.cmake	1970-01-01 00:00:00 +0000
+++ cmake/CompizTesting.cmake	2012-03-06 17:44:14 +0000
@@ -0,0 +1,14 @@
+# Based on gtest's GTEST_ADD_TESTS, but with run-with-xvfb.sh
+function(ENV_GTEST_ADD_TESTS executable extra_args)
+    if(NOT ARGN)
+        message(FATAL_ERROR "Missing ARGN")
+    endif()
+    foreach(source ${ARGN})
+        file(READ "${source}" contents)
+        string(REGEX MATCHALL "TEST_?F?\\(([A-Za-z_0-9 ,]+)\\)" found_tests ${contents})
+        foreach(hit ${found_tests})
+            string(REGEX REPLACE ".*\\( *([A-Za-z_0-9]+), *([A-Za-z_0-9]+) *\\).*" "\\1.\\2" test_name ${hit})
+            add_test(${test_name} "/bin/bash" "${CMAKE_SOURCE_DIR}/scripts/run-with-xvfb.sh" "./${executable} --gtest_filter=${test_name} ${extra_args}")
+        endforeach()
+    endforeach()
+endfunction()

=== added directory 'scripts'
=== added file 'scripts/run-with-xvfb.sh'
--- scripts/run-with-xvfb.sh	1970-01-01 00:00:00 +0000
+++ scripts/run-with-xvfb.sh	2012-03-06 17:44:14 +0000
@@ -0,0 +1,19 @@
+#!/bin/bash
+# Usage: /bin/bash run-with-xvfb.sh <program>
+#
+# Creates Xvfb instance and runs program in that instance. Shuts down Xvfb when done.
+
+if [ $# -ne 1 ]; then
+    echo "Usage /bin/bash run-with-xvfb.sh <program>"
+    exit 1
+fi
+
+if [ "x$DISPLAY" == "x" ]; then
+    Xvfb -ac -noreset -screen 0 1024x768x16 -help 2>/dev/null 1>&2
+    XID=`for id in 101 102 103 104 105 106 107 197 199 211 223 227 293 307 308 309 310 311 491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 991 992 993 994 995 996 997 998 999 1000 1001 1002 1003 1004 1005 1006 1007 1008 1009 4703 4721 4723 4729 4733 4751 9973 9974 9975 9976 9977 9978 9979 9980 9981 9982 9983 9984 9985 9986 9987 9988 9989 9990 9991 9992 9993 9994 9995 9996 9997 9998 9999 ; do test -e /tmp/.X$id-lock || { echo $id; exit 0; }; done; echo "No Display ports available, quit."; exit 1`
+    { Xvfb -ac -noreset -screen 0 1024x768x16 :$XID -screen 0 1024x768x16 -nolisten tcp -auth /dev/null >/dev/null 2>&1 & trap "kill -15 $! " 0 HUP INT QUIT TRAP USR1 PIPE TERM ; } || { echo "Gtk+Tests:ERROR: Failed to start Xvfb environment for X11 target tests."; exit 1; }
+    DISPLAY=:$XID $1
+else
+    echo "Note: You are already running an Xserver."
+    $1
+fi

=== modified file 'src/plugin/tests/CMakeLists.txt'
--- src/plugin/tests/CMakeLists.txt	2012-01-24 16:36:23 +0000
+++ src/plugin/tests/CMakeLists.txt	2012-03-06 17:44:14 +0000
@@ -1,3 +1,5 @@
+include(CompizTesting)
+
 include_directories( 
   ${CMAKE_CURRENT_SOURCE_DIR} 
 
@@ -30,4 +32,4 @@
   ${CMAKE_THREAD_LIBS_INIT} # Link in pthread.
 )
 
-gtest_add_tests( compiz_plugin_test "" ${CMAKE_CURRENT_SOURCE_DIR}/test-plugin.cpp )
+env_gtest_add_tests( compiz_plugin_test "" ${CMAKE_CURRENT_SOURCE_DIR}/test-plugin.cpp )

=== modified file 'src/privatescreen/tests/CMakeLists.txt'
--- src/privatescreen/tests/CMakeLists.txt	2012-03-01 16:53:51 +0000
+++ src/privatescreen/tests/CMakeLists.txt	2012-03-06 17:44:14 +0000
@@ -1,3 +1,5 @@
+include(CompizTesting)
+
 include_directories( 
   ${CMAKE_CURRENT_SOURCE_DIR} 
 
@@ -49,4 +51,4 @@
   ${CMAKE_THREAD_LIBS_INIT} # Link in pthread.
 )
 
-gtest_add_tests( compiz_privatescreen_test "" ${CMAKE_CURRENT_SOURCE_DIR}/test-privatescreen.cpp )
+env_gtest_add_tests( compiz_privatescreen_test "" ${CMAKE_CURRENT_SOURCE_DIR}/test-privatescreen.cpp )

=== modified file 'src/wrapsystem/tests/CMakeLists.txt'
--- src/wrapsystem/tests/CMakeLists.txt	2012-01-12 13:44:07 +0000
+++ src/wrapsystem/tests/CMakeLists.txt	2012-03-06 17:44:14 +0000
@@ -15,4 +15,4 @@
   ${CMAKE_THREAD_LIBS_INIT} # Link in pthread.
 )
 
-add_test( compiz_wrapsystem_test compiz_wrapsystem_test )
+add_test( compiz_wrapsystem_test "/bin/bash" "${CMAKE_SOURCE_DIR}/scripts/run-with-xvfb.sh" "./compiz_wrapsystem_test" )

